==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiCore/QChildEvent_shell.cpp <==
#include "QChildEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QChildEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QChildEvent")
    QChildEvent *_ptr = reinterpret_cast<QChildEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QChildEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QChildEvent_shell) ); }

jmethodID QChildEvent_shell::__shell_javaMethod(int pos) const { return QChildEvent_shell::__shell()->javaMethod(typeid(QChildEvent), pos); }

// emitting (writeShellConstructor)
QChildEvent_shell::QChildEvent_shell(QEvent::Type type0, QObject* child1)
    : QChildEvent(type0, child1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QChildEvent::QChildEvent_shell(QEvent::Type type0, QObject* child1)", QChildEvent_shell::__shell())
    QChildEvent_shell::__shell()->constructed(typeid(QChildEvent));
}

// emitting (writeShellDestructor)
QChildEvent_shell::~QChildEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QChildEvent::~QChildEvent()", QChildEvent_shell::__shell())
    QChildEvent_shell::__shell()->destructed(typeid(QChildEvent));
}

void QChildEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QChildEvent_shell*>(ptr)->QChildEvent_shell::__shell()->tryDeleteShell(typeid(QChildEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QChildEvent(QEvent::Type,QObject*)
void __qt_construct_QChildEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QChildEvent(QEvent::Type,QObject*)")
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    jobject child1 = __java_arguments[1].l;
    QObject* __qt_child1 = qtjambi_cast<QObject* >(__jni_env, child1);
    QChildEvent *__qt_this = new(__qtjambi_ptr) QChildEvent_shell(QEvent::Type(__qt_type0), __qt_child1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QChildEvent_shell
void __qt_destruct_QChildEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QChildEvent")
    reinterpret_cast<QChildEvent_shell*>(ptr)->~QChildEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QChildEvent::QChildEvent(QEvent::Type,QObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_initialize_1native__Lio_qt_core_QChildEvent_2Lio_qt_core_QEvent_00024Type_2Lio_qt_core_QObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jobject child1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QChildEvent::QChildEvent(QEvent::Type,QObject*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].l = child1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QChildEvent_0, sizeof(QChildEvent_shell), typeid(QChildEvent), true, &deleter_QChildEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QChildEvent::added()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_added_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::added()const", __qt_this)
        __java_return_value = __qt_this->added();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QChildEvent::child()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_child_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::child()const", __qt_this)
        QObject* __qt_return_value = __qt_this->child();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QChildEvent::polished()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_polished_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::polished()const", __qt_this)
        __java_return_value = __qt_this->polished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QChildEvent::removed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_removed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::removed()const", __qt_this)
        __java_return_value = __qt_this->removed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = QtJambiAPI::convertNativeToJavaOwnedObjectAsWrapper(__jni_env, new QChildEvent(*__qt_this));
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QChildEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QChildEvent>("QChildEvent", "io/qt/core/QChildEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QChildEvent, {
        ConstructorInfo(&__qt_construct_QChildEvent_0, "Lio/qt/core/QEvent$Type;Lio/qt/core/QObject;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QChildEvent);
    registerSizeOfShell(typeId, sizeof(QChildEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QChildEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiCore/QChildEvent_shell.cpp <==
#include "QChildEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QChildEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QChildEvent")
    QChildEvent *_ptr = reinterpret_cast<QChildEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QChildEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QChildEvent_shell) ); }

jmethodID QChildEvent_shell::__shell_javaMethod(int pos) const { return QChildEvent_shell::__shell()->javaMethod(typeid(QChildEvent), pos); }

// emitting (writeShellConstructor)
QChildEvent_shell::QChildEvent_shell(QEvent::Type type0, QObject* child1)
    : QChildEvent(type0, child1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QChildEvent::QChildEvent_shell(QEvent::Type type0, QObject* child1)", QChildEvent_shell::__shell())
    QChildEvent_shell::__shell()->constructed(typeid(QChildEvent));
}

// emitting (writeShellDestructor)
QChildEvent_shell::~QChildEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QChildEvent::~QChildEvent()", QChildEvent_shell::__shell())
    QChildEvent_shell::__shell()->destructed(typeid(QChildEvent));
}

void QChildEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QChildEvent_shell*>(ptr)->QChildEvent_shell::__shell()->tryDeleteShell(typeid(QChildEvent));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QChildEvent(QEvent::Type,QObject*)
void __qt_construct_QChildEvent_QEvent_Type_QObject_ptr(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QChildEvent(QEvent::Type,QObject*)")
    jobject type0 = __java_arguments[0].l;
    QEvent::Type __qt_type0 = qtjambi_cast<QEvent::Type>(__jni_env, type0);
    jobject child1 = __java_arguments[1].l;
    QObject* __qt_child1 = qtjambi_cast<QObject* >(__jni_env, child1);
    QChildEvent *__qt_this = new(__qtjambi_ptr) QChildEvent_shell(QEvent::Type(__qt_type0), __qt_child1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QChildEvent::QChildEvent(QEvent::Type,QObject*)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_initialize_1native__Lio_qt_core_QChildEvent_2Lio_qt_core_QEvent_00024Type_2Lio_qt_core_QObject_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject type0,
 jobject child1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QChildEvent::QChildEvent(QEvent::Type,QObject*)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = type0;
        arguments[1].l = child1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QChildEvent_QEvent_Type_QObject_ptr, sizeof(QChildEvent_shell), typeid(QChildEvent), true, &deleter_QChildEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QChildEvent_shell
void __qt_destruct_QChildEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QChildEvent")
    reinterpret_cast<QChildEvent_shell*>(ptr)->~QChildEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QChildEvent::added()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_added_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::added()const", __qt_this)
        __java_return_value = __qt_this->added();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QChildEvent::child()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_child_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::child()const", __qt_this)
        QObject* __qt_return_value = __qt_this->child();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QChildEvent::polished()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_polished_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::polished()const", __qt_this)
        __java_return_value = __qt_this->polished();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QChildEvent::removed()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_core_QChildEvent_removed_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QChildEvent *__qt_this = QtJambiAPI::objectFromNativeId<QChildEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QChildEvent::removed()const", __qt_this)
        __java_return_value = __qt_this->removed();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QChildEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QChildEvent>("QChildEvent", "io/qt/core/QChildEvent");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QChildEvent, {
        ConstructorInfo(&__qt_construct_QChildEvent_QEvent_Type_QObject_ptr, "Lio/qt/core/QEvent$Type;Lio/qt/core/QObject;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QChildEvent);
    registerSizeOfShell(typeId, sizeof(QChildEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QChildEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
